← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~suutari-olli/openlp/rename_Powerpoint_to_PowerPoint into lp:openlp

 

Azaziah has proposed merging lp:~suutari-olli/openlp/rename_Powerpoint_to_PowerPoint into lp:openlp.

Requested reviews:
  OpenLP Core (openlp-core)

For more details, see:
https://code.launchpad.net/~suutari-olli/openlp/rename_Powerpoint_to_PowerPoint/+merge/277238

At the moment PowerPoint is called as PowerPoint in the UI.

This branch renames all occurrences of "Powerpoint" to "PowerPoint"
The all small "powerpoint" is left un-touched.
Nothing else is changed in this branch.
Total count of replaced "Powerpoint" in text editor: 126

https://ci.openlp.io/view/Branch/job/Branch-05b-Test_Coverage/470/console
-- 
Your team OpenLP Core is requested to review the proposed merge of lp:~suutari-olli/openlp/rename_Powerpoint_to_PowerPoint into lp:openlp.
=== modified file 'openlp/plugins/presentations/lib/mediaitem.py'
--- openlp/plugins/presentations/lib/mediaitem.py	2015-06-02 21:13:15 +0000
+++ openlp/plugins/presentations/lib/mediaitem.py	2015-11-11 12:38:06 +0000
@@ -42,7 +42,7 @@
 class PresentationMediaItem(MediaManagerItem):
     """
     This is the Presentation media manager item for Presentation Items. It can present files using Openoffice and
-    Powerpoint
+    PowerPoint
     """
     log.info('Presentations Media Item loaded')
 

=== modified file 'openlp/plugins/presentations/lib/powerpointcontroller.py'
--- openlp/plugins/presentations/lib/powerpointcontroller.py	2015-06-16 07:47:42 +0000
+++ openlp/plugins/presentations/lib/powerpointcontroller.py	2015-11-11 12:38:06 +0000
@@ -48,19 +48,19 @@
 log = logging.getLogger(__name__)
 
 
-class PowerpointController(PresentationController):
+class PowerPointController(PresentationController):
     """
     Class to control interactions with PowerPoint Presentations. It creates the runtime Environment , Loads the and
     Closes the Presentation. As well as triggering the correct activities based on the users input.
     """
-    log.info('PowerpointController loaded')
+    log.info('PowerPointController loaded')
 
     def __init__(self, plugin):
         """
         Initialise the class
         """
         log.debug('Initialising')
-        super(PowerpointController, self).__init__(plugin, 'Powerpoint', PowerpointDocument)
+        super(PowerPointController, self).__init__(plugin, 'PowerPoint', PowerPointDocument)
         self.supports = ['ppt', 'pps', 'pptx', 'ppsx', 'pptm']
         self.process = None
 
@@ -116,7 +116,7 @@
             self.process = None
 
 
-class PowerpointDocument(PresentationDocument):
+class PowerPointDocument(PresentationDocument):
     """
     Class which holds information and controls a single presentation.
     """
@@ -128,8 +128,8 @@
         :param controller:
         :param presentation:
         """
-        log.debug('Init Presentation Powerpoint')
-        super(PowerpointDocument, self).__init__(controller, presentation)
+        log.debug('Init Presentation PowerPoint')
+        super(PowerPointDocument, self).__init__(controller, presentation)
         self.presentation = None
         self.index_map = {}
         self.slide_count = 0
@@ -155,7 +155,7 @@
                 Registry().get('main_window').activateWindow()
             return True
         except (AttributeError, pywintypes.com_error) as e:
-            log.exception('Exception caught while loading Powerpoint presentation')
+            log.exception('Exception caught while loading PowerPoint presentation')
             log.exception(e)
             trace_error_handler(log)
             return False
@@ -511,10 +511,10 @@
         try:
             self.presentation.SlideShowWindow.View.Exit()
         except (AttributeError, pywintypes.com_error) as e:
-            log.exception('Failed to exit Powerpoint presentation after error')
+            log.exception('Failed to exit PowerPoint presentation after error')
             log.exception(e)
-        critical_error_message_box(UiStrings().Error, translate('PresentationPlugin.PowerpointDocument',
-                                                                'An error occurred in the Powerpoint integration '
+        critical_error_message_box(UiStrings().Error, translate('PresentationPlugin.PowerPointDocument',
+                                                                'An error occurred in the PowerPoint integration '
                                                                 'and the presentation will be stopped. '
                                                                 'Restart the presentation if you wish to present it.'))
 

=== modified file 'openlp/plugins/presentations/lib/pptviewcontroller.py'
--- openlp/plugins/presentations/lib/pptviewcontroller.py	2015-01-18 13:39:21 +0000
+++ openlp/plugins/presentations/lib/pptviewcontroller.py	2015-11-11 12:38:06 +0000
@@ -55,7 +55,7 @@
         """
         log.debug('Initialising')
         self.process = None
-        super(PptviewController, self).__init__(plugin, 'Powerpoint Viewer', PptviewDocument)
+        super(PptviewController, self).__init__(plugin, 'PowerPoint Viewer', PptviewDocument)
         self.supports = ['ppt', 'pps', 'pptx', 'ppsx', 'pptm']
 
     def check_available(self):

=== modified file 'openlp/plugins/presentations/lib/presentationcontroller.py'
--- openlp/plugins/presentations/lib/presentationcontroller.py	2015-03-09 21:39:31 +0000
+++ openlp/plugins/presentations/lib/presentationcontroller.py	2015-11-11 12:38:06 +0000
@@ -352,7 +352,7 @@
     ``__init__``, ``check_available`` and ``presentation_deleted`` should always be implemented.
 
     See :class:`~openlp.plugins.presentations.lib.impresscontroller.ImpressController`,
-    :class:`~openlp.plugins.presentations.lib.powerpointcontroller.PowerpointController` or
+    :class:`~openlp.plugins.presentations.lib.powerpointcontroller.PowerPointController` or
     :class:`~openlp.plugins.presentations.lib.pptviewcontroller.PptviewController`
     for examples.
 

=== modified file 'openlp/plugins/presentations/lib/presentationtab.py'
--- openlp/plugins/presentations/presentationplugin.py	2015-10-16 16:49:58 +0000
+++ openlp/plugins/presentations/presentationplugin.py	2015-11-11 12:38:06 +0000
@@ -40,8 +40,8 @@
                         'presentations/enable_pdf_program': QtCore.Qt.Unchecked,
                         'presentations/pdf_program': '',
                         'presentations/Impress': QtCore.Qt.Checked,
-                        'presentations/Powerpoint': QtCore.Qt.Checked,
-                        'presentations/Powerpoint Viewer': QtCore.Qt.Checked,
+                        'presentations/PowerPoint': QtCore.Qt.Checked,
+                        'presentations/PowerPoint Viewer': QtCore.Qt.Checked,
                         'presentations/Pdf': QtCore.Qt.Checked,
                         'presentations/presentations files': [],
                         'presentations/thumbnail_scheme': '',

=== modified file 'openlp/plugins/songs/lib/importers/openoffice.py'
--- openlp/plugins/songs/lib/importers/openoffice.py	2015-08-28 10:22:06 +0000
+++ openlp/plugins/songs/lib/importers/openoffice.py	2015-11-11 12:38:06 +0000
@@ -49,7 +49,7 @@
 
 class OpenOfficeImport(SongImport):
     """
-    Import songs from Impress/Powerpoint docs using Impress
+    Import songs from Impress/PowerPoint docs using Impress
     """
     def __init__(self, manager, **kwargs):
         """

=== modified file 'resources/i18n/af.ts'
--- resources/i18n/af.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/af.ts	2015-11-11 12:38:06 +0000
@@ -7604,10 +7604,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/bg.ts'
--- resources/i18n/bg.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/bg.ts	2015-11-11 12:38:06 +0000
@@ -7565,10 +7565,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/cs.ts'
--- resources/i18n/cs.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/cs.ts	2015-11-11 12:38:06 +0000
@@ -7708,11 +7708,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Vznikla chyba se začlenění Powerpoint prezentace a prezentace bude zastavena. Pokud si přejete prezentaci zobrazit, spusťte ji znovu.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Vznikla chyba se začlenění PowerPoint prezentace a prezentace bude zastavena. Pokud si přejete prezentaci zobrazit, spusťte ji znovu.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/da.ts'
--- resources/i18n/da.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/da.ts	2015-11-11 12:38:06 +0000
@@ -7712,11 +7712,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Der opstod en fejl i Powerpoint-integrationen og presentationen vil blive stoppet. Start presentationen igen hvis du vil vise den.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Der opstod en fejl i PowerPoint-integrationen og presentationen vil blive stoppet. Start presentationen igen hvis du vil vise den.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/de.ts'
--- resources/i18n/de.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/de.ts	2015-11-11 12:38:06 +0000
@@ -7680,11 +7680,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Ein Fehler in der Powerpoint Integration ist aufgetreten und die Präsentation wird nun gestoppt. Um die Präsentation zu zeigen, muss diese neu gestartet werden.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Ein Fehler in der PowerPoint Integration ist aufgetreten und die Präsentation wird nun gestoppt. Um die Präsentation zu zeigen, muss diese neu gestartet werden.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/el.ts'
--- resources/i18n/el.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/el.ts	2015-11-11 12:38:06 +0000
@@ -7607,10 +7607,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/en.ts'
--- resources/i18n/en.ts	2015-10-15 17:34:42 +0000
+++ resources/i18n/en.ts	2015-11-11 12:38:06 +0000
@@ -7710,11 +7710,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/en_GB.ts'
--- resources/i18n/en_GB.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/en_GB.ts	2015-11-11 12:38:06 +0000
@@ -7709,11 +7709,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/en_ZA.ts'
--- resources/i18n/en_ZA.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/en_ZA.ts	2015-11-11 12:38:06 +0000
@@ -7710,11 +7710,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/es.ts'
--- resources/i18n/es.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/es.ts	2015-11-11 12:38:06 +0000
@@ -7712,10 +7712,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation>Se produjo un error con la integración de PowerPoint y se cerrará la presentación. Reinicie la presentación para mostrarla de nuevo.</translation>
     </message>
 </context>

=== modified file 'resources/i18n/et.ts'
--- resources/i18n/et.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/et.ts	2015-11-11 12:38:06 +0000
@@ -7709,11 +7709,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Powerpointi integratsioonil esines viga ja esitlus jääb pooleli. Alusta esitlust uuesti, kui sa siiski tahad seda näidata.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>PowerPointi integratsioonil esines viga ja esitlus jääb pooleli. Alusta esitlust uuesti, kui sa siiski tahad seda näidata.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/fi.ts'
--- resources/i18n/fi.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/fi.ts	2015-11-11 12:38:06 +0000
@@ -7849,11 +7849,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Tapahtui virhe Powerpoint integraatiossa ja esitys keskeytettiin. Käynnistä esitys uudellee, jos tahdot esittää sen.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Tapahtui virhe PowerPoint integraatiossa ja esitys keskeytettiin. Käynnistä esitys uudellee, jos tahdot esittää sen.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/fr.ts'
--- resources/i18n/fr.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/fr.ts	2015-11-11 12:38:06 +0000
@@ -7628,10 +7628,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/hu.ts'
--- resources/i18n/hu.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/hu.ts	2015-11-11 12:38:06 +0000
@@ -7711,11 +7711,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Hiba történt a Powerpoint integrációban, ezért a prezentáció leáll. Újraindítással lehet újra bemutatni a prezentációt.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Hiba történt a PowerPoint integrációban, ezért a prezentáció leáll. Újraindítással lehet újra bemutatni a prezentációt.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/id.ts'
--- resources/i18n/id.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/id.ts	2015-11-11 12:38:06 +0000
@@ -7711,10 +7711,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation>Terjadi kesalahan dalam integrasi PowerPoint dan presentasi akan dihentikan. Silakan mulai-ulang presentasi jika Anda ingin menampilkannya.</translation>
     </message>
 </context>

=== modified file 'resources/i18n/ja.ts'
--- resources/i18n/ja.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/ja.ts	2015-11-11 12:38:06 +0000
@@ -7705,10 +7705,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation>PowerPointとの通信にエラーが発生し、プレゼンテーションが終了しました。表示するには、プレゼンテーションをもう一度開始してください。</translation>
     </message>
 </context>

=== modified file 'resources/i18n/ko.ts'
--- resources/i18n/ko.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/ko.ts	2015-11-11 12:38:06 +0000
@@ -7578,10 +7578,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/lt.ts'
--- resources/i18n/lt.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/lt.ts	2015-11-11 12:38:06 +0000
@@ -7710,11 +7710,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Powerpoint integravime įvyko klaida ir pateiktis bus sustabdyta. Paleiskite pateiktį iš naujo, jei norite ją pristatyti.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>PowerPoint integravime įvyko klaida ir pateiktis bus sustabdyta. Paleiskite pateiktį iš naujo, jei norite ją pristatyti.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/nb.ts'
--- resources/i18n/nb.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/nb.ts	2015-11-11 12:38:06 +0000
@@ -7709,11 +7709,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Det oppstod en feil i Powerpointintegrasjonen og presentasjonen vil bli stoppet. Start presentasjonen på nytt hvis du ønsker å fortsette.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Det oppstod en feil i PowerPointintegrasjonen og presentasjonen vil bli stoppet. Start presentasjonen på nytt hvis du ønsker å fortsette.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/nl.ts'
--- resources/i18n/nl.ts	2015-10-15 17:34:42 +0000
+++ resources/i18n/nl.ts	2015-11-11 12:38:06 +0000
@@ -2419,7 +2419,7 @@
 OpenLP is written and maintained by volunteers. If you would like to see more free Christian software being written, please consider volunteering by using the button below.</source>
         <translation>OpenLP &lt;version&gt;&lt;revision&gt; - Open Source Lyrics Projection
 
-OpenLP is gratis presentatiesoftware voor kerken. Het kan gebruikt worden voor het projecteren van liedteksten, bijbelverzen, video&apos;s, afbeeldingen en zelfs bestaande presentaties uit Powerpoint.
+OpenLP is gratis presentatiesoftware voor kerken. Het kan gebruikt worden voor het projecteren van liedteksten, bijbelverzen, video&apos;s, afbeeldingen en zelfs bestaande presentaties uit PowerPoint.
 
 Lees meer over OpenLP: http://openlp.org/
 
@@ -7712,11 +7712,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Er is een fout opgetreden in de Powerpoint-integratie waardoor de presentatie zal worden gestopt. U kunt de presentatie herstarten om verder te gaan met presenteren.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Er is een fout opgetreden in de PowerPoint-integratie waardoor de presentatie zal worden gestopt. U kunt de presentatie herstarten om verder te gaan met presenteren.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/pl.ts'
--- resources/i18n/pl.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/pl.ts	2015-11-11 12:38:06 +0000
@@ -7709,11 +7709,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Wystąpił błąd we współpracy z Powerpointem i prezentacja zostanie zatrzymana. Uruchom ją ponownie, jeśli chcesz ją zaprezentować.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Wystąpił błąd we współpracy z PowerPointem i prezentacja zostanie zatrzymana. Uruchom ją ponownie, jeśli chcesz ją zaprezentować.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/pt_BR.ts'
--- resources/i18n/pt_BR.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/pt_BR.ts	2015-11-11 12:38:06 +0000
@@ -7612,10 +7612,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/ru.ts'
--- resources/i18n/ru.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/ru.ts	2015-11-11 12:38:06 +0000
@@ -7661,10 +7661,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/sk.ts'
--- resources/i18n/sk.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/sk.ts	2015-11-11 12:38:06 +0000
@@ -7691,11 +7691,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Vznikla chyba pri integrácií Powerpointu a prezentácia bude ukončená. Ak chete zobraziť prezentáciu, spustite ju znovu.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Vznikla chyba pri integrácií PowerPointu a prezentácia bude ukončená. Ak chete zobraziť prezentáciu, spustite ju znovu.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/sv.ts'
--- resources/i18n/sv.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/sv.ts	2015-11-11 12:38:06 +0000
@@ -7710,11 +7710,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>Ett fel inträffade i Powerpoint-integrationen och presentationen kommer att avbrytas. Starta om presentationen om du vill visa den.</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>Ett fel inträffade i PowerPoint-integrationen och presentationen kommer att avbrytas. Starta om presentationen om du vill visa den.</translation>
     </message>
 </context>
 <context>

=== modified file 'resources/i18n/ta_LK.ts'
--- resources/i18n/ta_LK.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/ta_LK.ts	2015-11-11 12:38:06 +0000
@@ -7606,10 +7606,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/th_TH.ts'
--- resources/i18n/th_TH.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/th_TH.ts	2015-11-11 12:38:06 +0000
@@ -7606,10 +7606,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/zh_CN.ts'
--- resources/i18n/zh_CN.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/zh_CN.ts	2015-11-11 12:38:06 +0000
@@ -7603,10 +7603,10 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
         <translation type="unfinished"/>
     </message>
 </context>

=== modified file 'resources/i18n/zh_TW.ts'
--- resources/i18n/zh_TW.ts	2015-10-15 16:55:00 +0000
+++ resources/i18n/zh_TW.ts	2015-11-11 12:38:06 +0000
@@ -7706,11 +7706,11 @@
     </message>
 </context>
 <context>
-    <name>PresentationPlugin.PowerpointDocument</name>
+    <name>PresentationPlugin.PowerPointDocument</name>
     <message>
         <location filename="openlp/plugins/presentations/lib/powerpointcontroller.py" line="517"/>
-        <source>An error occurred in the Powerpoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
-        <translation>整合Powerpoint時發生了錯誤,簡報即將結束。若您希望顯示,請重新啟動簡報。</translation>
+        <source>An error occurred in the PowerPoint integration and the presentation will be stopped. Restart the presentation if you wish to present it.</source>
+        <translation>整合PowerPoint時發生了錯誤,簡報即將結束。若您希望顯示,請重新啟動簡報。</translation>
     </message>
 </context>
 <context>

=== modified file 'tests/functional/openlp_plugins/presentations/test_mediaitem.py'
--- tests/functional/openlp_plugins/presentations/test_mediaitem.py	2015-03-18 22:04:30 +0000
+++ tests/functional/openlp_plugins/presentations/test_mediaitem.py	2015-11-11 12:38:06 +0000
@@ -68,8 +68,8 @@
         # Mock the controllers.
         self.media_item.controllers = {
             'Impress': impress_controller,
-            'Powerpoint': presentation_controller,
-            'Powerpoint Viewer': presentation_viewer_controller,
+            'PowerPoint': presentation_controller,
+            'PowerPoint Viewer': presentation_viewer_controller,
             'Pdf': pdf_controller
         }
 

=== modified file 'tests/functional/openlp_plugins/presentations/test_powerpointcontroller.py'
--- openlp/plugins/presentations/lib/presentationtab.py	2015-06-02 21:16:10 +0000
+++ openlp/plugins/presentations/lib/presentationtab.py	2015-11-11 12:38:06 +0000
@@ -148,10 +148,10 @@
             controller = self.controllers[key]
             checkbox = self.presenter_check_boxes[controller.name]
             checkbox.setChecked(Settings().value(self.settings_section + '/' + controller.name))
-            if controller.name == 'Powerpoint' and controller.is_available():
+            if controller.name == 'PowerPoint' and controller.is_available():
                 powerpoint_available = True
         self.override_app_check_box.setChecked(Settings().value(self.settings_section + '/override app'))
         # Load Powerpoint settings
         self.ppt_slide_click_check_box.setChecked(Settings().value(self.settings_section +
                                                                    '/powerpoint slide click advance'))
         self.ppt_slide_click_check_box.setEnabled(powerpoint_available)
@@ -148,10 +148,10 @@
                 powerpoint_available = True
         self.override_app_check_box.setChecked(Settings().value(self.settings_section + '/override app'))
-        # Load Powerpoint settings
+        # Load PowerPoint settings
         self.ppt_slide_click_check_box.setChecked(Settings().value(self.settings_section +
                                                                    '/powerpoint slide click advance'))

=== modified file 'openlp/plugins/presentations/presentationplugin.py'
--- tests/functional/openlp_plugins/presentations/test_powerpointcontroller.py	2015-05-05 13:20:24 +0000
+++ tests/functional/openlp_plugins/presentations/test_powerpointcontroller.py	2015-11-11 12:38:06 +0000
@@ -31,7 +31,7 @@
 from tests.helpers.testmixin import TestMixin
 from tests.utils.constants import TEST_RESOURCES_PATH
 
-from openlp.plugins.presentations.lib.powerpointcontroller import PowerpointController, PowerpointDocument,\
+from openlp.plugins.presentations.lib.powerpointcontroller import PowerPointController, PowerPointDocument,\
     _get_text_from_shapes
 from openlp.core.common import is_win, Settings
 
@@ -43,9 +43,9 @@
 }
 
 
-class TestPowerpointController(TestCase, TestMixin):
+class TestPowerPointController(TestCase, TestMixin):
     """
-    Test the PowerpointController Class
+    Test the PowerPointController Class
     """
 
     def setUp(self):
@@ -67,22 +67,22 @@
 
     def constructor_test(self):
         """
         Test the Constructor from the PowerpointController
         """
         # GIVEN: No presentation controller
         controller = None
 
         # WHEN: The presentation controller object is created
-        controller = PowerpointController(plugin=self.mock_plugin)
+        controller = PowerPointController(plugin=self.mock_plugin)
 
         # THEN: The name of the presentation controller should be correct
-        self.assertEqual('Powerpoint', controller.name,
+        self.assertEqual('PowerPoint', controller.name,
                          'The name of the presentation controller should be correct')
 
 
-class TestPowerpointDocument(TestCase, TestMixin):
+class TestPowerPointDocument(TestCase, TestMixin):
     """
-    Test the PowerpointDocument Class
+    Test the PowerPointDocument Class
     """
 
     def setUp(self):
@@ -95,7 +95,7 @@
         self.temp_folder = mkdtemp()
         self.mock_plugin.settings_section = self.temp_folder
         self.powerpoint_document_stop_presentation_patcher = patch(
-            'openlp.plugins.presentations.lib.powerpointcontroller.PowerpointDocument.stop_presentation')
+            'openlp.plugins.presentations.lib.powerpointcontroller.PowerPointDocument.stop_presentation')
         self.presentation_document_get_temp_folder_patcher = patch(
             'openlp.plugins.presentations.lib.powerpointcontroller.PresentationDocument.get_temp_folder')
         self.presentation_document_setup_patcher = patch(
@@ -107,7 +107,7 @@
         self.mock_presentation = MagicMock()
         self.mock_presentation_document_get_temp_folder.return_value = 'temp folder'
         self.file_name = os.path.join(TEST_RESOURCES_PATH, 'presentations', 'test.pptx')
-        self.real_controller = PowerpointController(self.mock_plugin)
+        self.real_controller = PowerPointController(self.mock_plugin)
         Settings().extend_default_settings(__default_settings__)
 
     def tearDown(self):
@@ -122,13 +122,13 @@
 
     def show_error_msg_test(self):
         """
-        Test the PowerpointDocument.show_error_msg() method gets called on com exception
+        Test the PowerPointDocument.show_error_msg() method gets called on com exception
         """
         if is_win():
             # GIVEN: A PowerpointDocument with mocked controller and presentation
             with patch('openlp.plugins.presentations.lib.powerpointcontroller.critical_error_message_box') as \
                     mocked_critical_error_message_box:
-                instance = PowerpointDocument(self.mock_controller, self.mock_presentation)
+                instance = PowerPointDocument(self.mock_controller, self.mock_presentation)
                 instance.presentation = MagicMock()
                 instance.presentation.SlideShowWindow.View.GotoSlide = MagicMock(side_effect=pywintypes.com_error('1'))
                 instance.index_map[42] = 42
@@ -137,7 +137,7 @@
                 instance.goto_slide(42)
 
                 # THEN: mocked_critical_error_message_box should have been called
-                mocked_critical_error_message_box.assert_called_with('Error', 'An error occurred in the Powerpoint '
+                mocked_critical_error_message_box.assert_called_with('Error', 'An error occurred in the PowerPoint '
                                                                      'integration and the presentation will be stopped.'
                                                                      ' Restart the presentation if you wish to '
                                                                      'present it.')
@@ -148,8 +148,8 @@
         Test loading a document in PowerPoint
         """
         if is_win() and self.real_controller.check_available():
-            # GIVEN: A PowerpointDocument and a presentation
-            doc = PowerpointDocument(self.real_controller, self.file_name)
+            # GIVEN: A PowerPointDocument and a presentation
+            doc = PowerPointDocument(self.real_controller, self.file_name)
 
             # WHEN: loading the filename
             doc.load_presentation()
@@ -158,19 +158,19 @@
             # THEN: result should be true
             self.assertEqual(result, True, 'The result should be True')
         else:
-            self.skipTest('Powerpoint not available, skipping test.')
+            self.skipTest('PowerPoint not available, skipping test.')
 
     def create_titles_and_notes_test(self):
         """
         Test creating the titles from PowerPoint
         """
         # GIVEN: mocked save_titles_and_notes, _get_text_from_shapes and two mocked slides
-        self.doc = PowerpointDocument(self.mock_controller, self.file_name)
+        self.doc = PowerPointDocument(self.mock_controller, self.file_name)
         self.doc.get_slide_count = MagicMock()
         self.doc.get_slide_count.return_value = 2
         self.doc.index_map = {1: 1, 2: 2}
         self.doc.save_titles_and_notes = MagicMock()
-        self.doc._PowerpointDocument__get_text_from_shapes = MagicMock()
+        self.doc._PowerPointDocument__get_text_from_shapes = MagicMock()
         slide = MagicMock()
         slide.Shapes.Title.TextFrame.TextRange.Text = 'SlideText'
         pres = MagicMock()
@@ -188,9 +188,9 @@
         Test creating the titles from PowerPoint when it returns no slides
         """
         # GIVEN: mocked save_titles_and_notes, _get_text_from_shapes and two mocked slides
-        doc = PowerpointDocument(self.mock_controller, self.file_name)
+        doc = PowerPointDocument(self.mock_controller, self.file_name)
         doc.save_titles_and_notes = MagicMock()
-        doc._PowerpointDocument__get_text_from_shapes = MagicMock()
+        doc._PowerPointDocument__get_text_from_shapes = MagicMock()
         pres = MagicMock()
         pres.Slides = []
         doc.presentation = pres
@@ -236,7 +236,7 @@
         Test that goto_slide goes to next effect if the slide is already displayed
         """
         # GIVEN: A Document with mocked controller, presentation, and mocked functions get_slide_number and next_step
-        doc = PowerpointDocument(self.mock_controller, self.mock_presentation)
+        doc = PowerPointDocument(self.mock_controller, self.mock_presentation)
         doc.presentation = MagicMock()
         doc.presentation.SlideShowWindow.View.GetClickIndex.return_value = 1
         doc.presentation.SlideShowWindow.View.GetClickCount.return_value = 2
@@ -256,7 +256,7 @@
         Test that blank_screen works as expected
         """
         # GIVEN: A Document with mocked controller, presentation, and mocked function get_slide_number
-        doc = PowerpointDocument(self.mock_controller, self.mock_presentation)
+        doc = PowerPointDocument(self.mock_controller, self.mock_presentation)
         doc.presentation = MagicMock()
         doc.presentation.SlideShowWindow.View.GetClickIndex.return_value = 3
         doc.presentation.Application.Version = 14.0
@@ -280,7 +280,7 @@
             mocked_screen_list_ret = MagicMock()
             mocked_screen_list_ret.screen_list = [1]
             mocked_screen_list.return_value = mocked_screen_list_ret
-            doc = PowerpointDocument(self.mock_controller, self.mock_presentation)
+            doc = PowerPointDocument(self.mock_controller, self.mock_presentation)
             doc.presentation = MagicMock()
             doc.presentation.SlideShowWindow.View.GetClickIndex.return_value = 3
             doc.presentation.Application.Version = 14.0
@@ -67,22 +67,22 @@
     def constructor_test(self):
         """
-        Test the Constructor from the PowerpointController
+        Test the Constructor from the PowerPointController
         """
         # GIVEN: No presentation controller
@@ -122,13 +122,13 @@
         """
         if is_win():
-            # GIVEN: A PowerpointDocument with mocked controller and presentation
+            # GIVEN: A PowerPointDocument with mocked controller and presentation
             with patch('openlp.plugins.presentations.lib.powerpointcontroller.critical_error_message_box') as \
                     mocked_critical_error_message_box:

=== modified file 'tests/functional/openlp_plugins/presentations/test_pptviewcontroller.py'
--- tests/functional/openlp_plugins/presentations/test_pptviewcontroller.py	2015-01-18 13:39:21 +0000
+++ tests/functional/openlp_plugins/presentations/test_pptviewcontroller.py	2015-11-11 12:38:06 +0000
@@ -76,7 +76,7 @@
         controller = PptviewController(plugin=self.mock_plugin)
 
         # THEN: The name of the presentation controller should be correct
-        self.assertEqual('Powerpoint Viewer', controller.name,
+        self.assertEqual('PowerPoint Viewer', controller.name,
                          'The name of the presentation controller should be correct')
 
     def check_available_test(self):
@@ -204,7 +204,7 @@
 
     def create_titles_and_notes_test(self):
         """
-        Test PowerpointController.create_titles_and_notes
+        Test PowerPointController.create_titles_and_notes
         """
         # GIVEN: mocked PresentationController.save_titles_and_notes and a pptx file
         doc = PptviewDocument(self.mock_controller, self.mock_presentation)
@@ -221,7 +221,7 @@
 
     def create_titles_and_notes_nonexistent_file_test(self):
         """
         Test PowerpointController.create_titles_and_notes with nonexistent file
         """
         # GIVEN: mocked PresentationController.save_titles_and_notes and an nonexistent file
         with patch('builtins.open') as mocked_open, \
@@ -244,7 +244,7 @@
 
     def create_titles_and_notes_invalid_file_test(self):
         """
         Test PowerpointController.create_titles_and_notes with invalid file
         """
         # GIVEN: mocked PresentationController.save_titles_and_notes and an invalid file
         with patch('builtins.open') as mocked_open, \
@@ -221,7 +221,7 @@
     def create_titles_and_notes_nonexistent_file_test(self):
         """
-        Test PowerpointController.create_titles_and_notes with nonexistent file
+        Test PowerPointController.create_titles_and_notes with nonexistent file
         """
         # GIVEN: mocked PresentationController.save_titles_and_notes and an nonexistent file
@@ -244,7 +244,7 @@
     def create_titles_and_notes_invalid_file_test(self):
         """
-        Test PowerpointController.create_titles_and_notes with invalid file
+        Test PowerPointController.create_titles_and_notes with invalid file
         """
         # GIVEN: mocked PresentationController.save_titles_and_notes and an invalid file


Follow ups